@@ -41,6 +41,8 @@ pub struct App {
     /// path of the chess engine
     pub chess_engine_path: Option<String>,
     pub log_level: LevelFilter,
+    /// Bot thinking depth for chess engine
+    pub bot_depth: u8,
 }
 
 impl Default for App {
@@ -56,6 +58,7 @@ impl Default for App {
             menu_cursor: 0,
             chess_engine_path: None,
             log_level: LevelFilter::Off,
+            bot_depth: 10,
         }
     }
 }
@@ -68,6 +71,10 @@ impl App {
             self.current_popup = Some(Popups::Help);
         }
     }
+
+    pub fn show_end_screen(&mut self) {
+        self.current_popup = Some(Popups::EndScreen);
+    }
     pub fn toggle_credit_popup(&mut self) {
         if self.current_page == Pages::Home {
             self.current_page = Pages::Credit;
@@ -200,11 +207,12 @@ impl App {
             None => &empty,
         };
 
-        // if the selected Color is Black, we need to switch the Game
         if let Some(color) = self.selected_color {
-            if color == PieceColor::Black {
-                self.game.bot = Some(Bot::new(path, true));
+            let is_bot_starting = color == PieceColor::Black;
+            self.game.bot = Some(Bot::new(path, is_bot_starting, self.bot_depth));
 
+            // If the bot is starting (player is black), execute the bot's first move
+            if is_bot_starting {
                 self.game.execute_bot_move();
                 self.game.player_turn = PieceColor::Black;
             }
@@ -281,6 +289,10 @@ impl App {
                 "log_level".to_string(),
                 Value::String(self.log_level.to_string().to_string()),
             );
+            table.insert(
+                "bot_depth".to_string(),
+                Value::Integer(self.bot_depth as i64),
+            );
         }
 
         let mut file = File::create(config_path.clone()).unwrap();
@@ -295,5 +307,38 @@ impl App {
         self.host_ip = None;
         self.menu_cursor = 0;
         self.chess_engine_path = None;
+        self.bot_depth = 10;
+    }
+
+    pub fn go_left_in_game(&mut self) {
+        let authorized_positions = self
+            .game
+            .game_board
+            .get_authorized_positions(self.game.player_turn, self.game.ui.selected_coordinates);
+        self.game.ui.cursor_left(authorized_positions);
+    }
+
+    pub fn go_right_in_game(&mut self) {
+        let authorized_positions = self
+            .game
+            .game_board
+            .get_authorized_positions(self.game.player_turn, self.game.ui.selected_coordinates);
+        self.game.ui.cursor_right(authorized_positions);
+    }
+
+    pub fn go_up_in_game(&mut self) {
+        let authorized_positions = self
+            .game
+            .game_board
+            .get_authorized_positions(self.game.player_turn, self.game.ui.selected_coordinates);
+        self.game.ui.cursor_up(authorized_positions);
+    }
+
+    pub fn go_down_in_game(&mut self) {
+        let authorized_positions = self
+            .game
+            .game_board
+            .get_authorized_positions(self.game.player_turn, self.game.ui.selected_coordinates);
+        self.game.ui.cursor_down(authorized_positions);
     }
 }
