@@ -1,8 +1,8 @@
 use super::{coord::Coord, game::Game};
 use crate::{
     constants::{DisplayMode, BLACK, UNDEFINED_POSITION, WHITE},
-    pieces::{PieceColor, PieceMove, PieceType},
-    ui::main_ui::render_cell,
+    pieces::{PieceColor, PieceType},
+    ui::{main_ui::render_cell, prompt::Prompt},
     utils::{convert_position_into_notation, get_cell_paragraph, invert_position},
 };
 use ratatui::{
@@ -35,6 +35,8 @@ pub struct UI {
     pub mouse_used: bool,
     /// The skin of the game
     pub display_mode: DisplayMode,
+    // The prompt for the player
+    pub prompt: Prompt,
 }
 
 impl Default for UI {
@@ -51,6 +53,7 @@ impl Default for UI {
             height: 0,
             mouse_used: false,
             display_mode: DisplayMode::DEFAULT,
+            prompt: Prompt::new(),
         }
     }
 }
@@ -107,8 +110,7 @@ impl UI {
         }
     }
 
-    /// CURSOR MOVEMENT
-
+    // CURSOR MOVEMENT
     /// Move the cursor up
     pub fn cursor_up(&mut self, authorized_positions: Vec<Coord>) {
         if self.is_cell_selected() {
@@ -169,7 +171,7 @@ impl UI {
     }
 
     /// Method to render the right panel history
-    pub fn history_render(&self, area: Rect, frame: &mut Frame, move_history: &[PieceMove]) {
+    pub fn history_render(&self, area: Rect, frame: &mut Frame, game: &Game) {
         // We write the history board on the side
         let history_block = Block::default()
             .title("History")
@@ -180,32 +182,40 @@ impl UI {
 
         let mut lines: Vec<Line> = vec![];
 
-        for i in (0..move_history.len()).step_by(2) {
-            let piece_type_from = move_history[i].piece_type;
+        for i in (0..game.game_board.move_history.len()).step_by(2) {
+            let piece_type_from = game.game_board.move_history[i].piece_type;
 
             let utf_icon_white =
                 PieceType::piece_to_utf_enum(&piece_type_from, Some(PieceColor::White));
             let move_white = convert_position_into_notation(&format!(
                 "{}{}{}{}",
-                move_history[i].from.row,
-                move_history[i].from.col,
-                move_history[i].to.row,
-                move_history[i].to.col
+                game.game_board.move_history[i].from.row,
+                game.game_board.move_history[i].from.col,
+                game.game_board.move_history[i].to.row,
+                game.game_board.move_history[i].to.col
             ));
 
             let mut utf_icon_black = "   ";
             let mut move_black: String = "   ".to_string();
 
             // If there is something for black
-            if i + 1 < move_history.len() {
-                let piece_type_to = move_history[i + 1].piece_type;
+            if i + 1 < game.game_board.move_history.len() {
+                let piece_type_to = game.game_board.move_history[i + 1].piece_type;
+                let black_move = &game.game_board.move_history[i + 1];
+
+                // Invert black moves if not playing against bot
+                let (from, to) = if game.bot.is_none() {
+                    (
+                        invert_position(&black_move.from),
+                        invert_position(&black_move.to),
+                    )
+                } else {
+                    (black_move.from, black_move.to)
+                };
 
                 move_black = convert_position_into_notation(&format!(
                     "{}{}{}{}",
-                    move_history[i + 1].from.row,
-                    move_history[i + 1].from.col,
-                    move_history[i + 1].to.row,
-                    move_history[i + 1].to.col
+                    from.row, from.col, to.row, to.col
                 ));
                 utf_icon_black =
                     PieceType::piece_to_utf_enum(&piece_type_to, Some(PieceColor::Black));
@@ -216,7 +226,7 @@ impl UI {
                 Span::styled(format!("{utf_icon_white} "), Style::default().fg(WHITE)), // white symbol
                 Span::raw(move_white.to_string()), // white move
                 Span::raw("     "),                // separator
-                Span::styled(format!("{utf_icon_black} "), Style::default().fg(WHITE)), // white symbol
+                Span::styled(format!("{utf_icon_black} "), Style::default().fg(WHITE)), // black symbol
                 Span::raw(move_black.to_string()), // black move
             ]));
         }
@@ -321,7 +331,7 @@ impl UI {
     }
 
     /// Method to render the board
-    pub fn board_render(&mut self, area: Rect, frame: &mut Frame, game: &Game) {
+    pub fn board_render(&mut self, area: Rect, frame: &mut Frame<'_>, game: &Game) {
         let width = area.width / 8;
         let height = area.height / 8;
         let border_height = area.height / 2 - (4 * height);
@@ -383,7 +393,7 @@ impl UI {
                 if !game.game_board.move_history.is_empty() {
                     last_move = game.game_board.move_history.last();
                     if game.bot.is_some()
-                        && !game.bot.as_ref().map_or(false, |bot| bot.is_bot_starting)
+                        && !game.bot.as_ref().is_some_and(|bot| bot.is_bot_starting)
                     {
                         last_move_from = last_move.map(|m| m.from).unwrap();
                         last_move_to = last_move.map(|m| m.to).unwrap();
@@ -391,6 +401,14 @@ impl UI {
                         last_move_from = invert_position(&last_move.map(|m| m.from).unwrap());
                         last_move_to = invert_position(&last_move.map(|m| m.to).unwrap());
                     }
+
+                    // If the opponent is the same as the last move player, we don't want to show his last move
+                    if game.opponent.is_some()
+                        && game.opponent.as_ref().unwrap().color == game.player_turn
+                    {
+                        last_move_from = Coord::undefined();
+                        last_move_to = Coord::undefined();
+                    }
                 }
 
                 let mut positions: Vec<Coord> = vec![];
@@ -447,7 +465,7 @@ impl UI {
                 }
                 // Draw the cell green if this is the selected cell or if the cell is part of the last move
                 else if (i == self.selected_coordinates.row && j == self.selected_coordinates.col)
-                    || (last_move_from == Coord::new(i, j) // If the last move from 
+                    || (last_move_from == Coord::new(i, j) // If the last move from
                         || (last_move_to == Coord::new(i, j) // If last move to
                             && !is_cell_in_positions(&positions, i, j)))
                 // and not in the authorized positions (grey instead of green)
