@@ -7,6 +7,8 @@ pub mod event;
 /// Widget renderer.
 pub mod ui;
 
+pub mod server;
+
 /// Event handler.
 pub mod handler;
 
@@ -21,3 +23,6 @@ pub mod constants;
 
 // Utils methods for the board
 pub mod utils;
+
+// Logging
+pub mod logging;
