@@ -9,7 +9,7 @@ use ratatui::{
 
 use crate::{
     constants::Popups,
-    game_logic::{bot::Bot, game::GameState},
+    game_logic::game::GameState,
     ui::popups::{
         render_color_selection_popup, render_credit_popup, render_end_popup,
         render_engine_path_error_popup, render_help_popup, render_promotion_popup,
@@ -61,9 +61,7 @@ pub fn render(app: &mut App, frame: &mut Frame<'_>) {
         } else if app.selected_color.is_none() {
             app.current_popup = Some(Popups::ColorSelection);
         } else if app.game.bot.is_none() {
-            let engine_path = app.chess_engine_path.clone().unwrap();
-            let is_bot_starting = app.selected_color.unwrap() == PieceColor::Black;
-            app.game.bot = Some(Bot::new(engine_path.as_str(), is_bot_starting));
+            app.bot_setup();
         } else {
             render_game_ui(frame, app, main_area);
         }
@@ -274,14 +272,16 @@ pub fn render_game_ui(frame: &mut Frame<'_>, app: &mut App, main_area: Rect) {
             PieceColor::Black => "Black",
         };
 
-        render_end_popup(
-            frame,
-            &format!("{string_color} Won !!!"),
-            app.game.opponent.is_some(),
-        );
+        if app.current_popup == Some(Popups::EndScreen) {
+            render_end_popup(
+                frame,
+                &format!("{string_color} Won !!!"),
+                app.game.opponent.is_some(),
+            );
+        }
     }
 
-    if app.game.game_state == GameState::Draw {
+    if app.game.game_state == GameState::Draw && app.current_popup == Some(Popups::EndScreen) {
         render_end_popup(frame, "That's a draw", app.game.opponent.is_some());
     }
 }
