@@ -6,7 +6,7 @@ const sidebars: SidebarsConfig = {
     {
       type: 'category',
       label: 'Installation', 
-      items: ['Installation/Packaging status', 'Installation/Cargo', 'Installation/Build from source', 'Installation/NetBSD', 'Installation/Arch Linux', 'Installation/NixOS', 'Installation/Docker'], 
+      items: ['Installation/Packaging status', 'Installation/Binary', 'Installation/Cargo', 'Installation/Build from source', 'Installation/NetBSD', 'Installation/Arch Linux', 'Installation/NixOS', 'Installation/Docker'], 
     },
     {
       type: 'category',
@@ -16,6 +16,7 @@ const sidebars: SidebarsConfig = {
         'Configuration/display',
         'Configuration/logging',
         'Configuration/engine',
+        'Configuration/bot',
       ],
     },
     {
